[PATCH 02/10] Update expected runtime of VPM-B test to match benchmark

Rick Walsh rickmwalsh at gmail.com
Sat Aug 29 05:38:29 PDT 2015


Signed-off-by: Rick Walsh <rickmwalsh at gmail.com>
---
 tests/testplan.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/testplan.cpp b/tests/testplan.cpp
index 737a085..3764882 100644
--- a/tests/testplan.cpp
+++ b/tests/testplan.cpp
@@ -413,8 +413,8 @@ void TestPlan::testVpmbMetric100m60min()
 	QCOMPARE(ev->gas.index, 2);
 	QCOMPARE(ev->value, 100);
 	QCOMPARE(get_depth_at_time(&displayed_dive.dc, ev->time.seconds), 6000);
-	// check expected run time of 316 minutes
-	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 316u * 60u + 20u));
+	// check expected run time of 311 minutes
+	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 311u * 60u + 20u));
 }
 
 void TestPlan::testVpmbMetricMultiLevelAir()
-- 
2.4.3



More information about the subsurface mailing list